import { Token, IContainer, InjectToken, Type } from '@ts-ioc/core';
import { ModuleConfigure, BootOptions } from '../modules';
/**
 * boot.
 *
 * @export
 * @interface IBoot
 * @template T
 */
export interface IRunnable<T> {
    /**
     * container.
     *
     * @type {IContainer}
     * @memberof IBoot
     */
    container: IContainer;
    /**
     * target instance.
     *
     * @type {T}
     * @memberof IBoot
     */
    getTarget(): T;
    /**
     * get target token.
     *
     * @returns {Token<T>}
     * @memberof IBoot
     */
    getTargetType(): Token<T>;
    /**
     * on boot init.
     *
     * @param {BootOptions<T>} options
     * @returns {Promise<void>}
     * @memberof IBoot
     */
    onInit?(options: BootOptions<T>): Promise<void>;
}
export interface RunnableOptions<T> {
    /**
     * module token
     *
     * @type {Token<any>}
     * @memberof RunnableOptions
     */
    mdToken?: Token<any>;
    /**
     * bootstrap type.
     *
     * @type {Type<T>}
     * @memberof RunnableOptions
     */
    type: Type<T>;
    /**
     * bootstrap instance.
     *
     * @type {T}
     * @memberof RunnableOptions
     */
    instance: T;
    /**
     * bootstrap configure.
     *
     * @type {ModuleConfigure}
     * @memberof RunnableOptions
     */
    config: ModuleConfigure;
    /**
     *  custom boot data of `BuildOptions`
     *
     * @type {*}
     * @memberof RunnableOptions
     */
    data?: any;
}
/**
 * runnable options token.
 */
export declare const RunnableOptionsToken: InjectToken<RunnableOptions<any>>;
/**
 * boot.
 *
 * @export
 * @class Boot
 * @implements {IBoot<T>}
 * @template T
 */
export declare class RunnableBase<T> implements IRunnable<T> {
    protected options: RunnableOptions<T>;
    container: IContainer;
    constructor(options: RunnableOptions<T>);
    getTarget(): T;
    getModuleToken(): Token<any>;
    getTargetType(): Type<T>;
    static getClassAnnations(): any;
}
/**
 * target is Runnable or not.
 *
 * @export
 * @param {*} target
 * @returns {target is RunnableBase<any>}
 */
export declare function isRunnable(target: any): target is RunnableBase<any>;
